Documentation
¶
Index ¶
- func Fatal(args ...interface{})
- func Fatalf(format string, args ...interface{})
- func General(args ...interface{})
- func Generalf(format string, args ...interface{})
- func Init(consolLog, fileLog bool, maxLogDays int, pathToLogDir string)
- func Kill()
- func Startup(args ...interface{})
- func Startupf(format string, args ...interface{})
- func Warning(args ...interface{})
- func Warningf(format string, args ...interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fatal ¶
func Fatal(args ...interface{})
Fatal is used to log something a server killing circumstance same as log.Fatalln() This will terminate the process with an exit code of 1
func Fatalf ¶
func Fatalf(format string, args ...interface{})
Fatalf is used to log something a server killing circumstance Formats the text before sending it
func Generalf ¶
func Generalf(format string, args ...interface{})
Generalf is used to log general stuff Formats the text before sending it
func Init ¶
Init initialises the srvlog package. if either consoleLog or fileLog is true it will start the logger in another gorutine ready to log
func Startup ¶
func Startup(args ...interface{})
Startup used to log the startup message example "Startup("Server listening on port:", PORT)"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.